package com.ruoyi.model.service;

import java.util.List;
import com.ruoyi.model.domain.AppTransactionDetails;

/**
 * 交易明细记录Service接口
 * 
 * @author ruoyi
 * @date 2025-03-08
 */
public interface IAppTransactionDetailsService 
{
    /**
     * 查询交易明细记录
     * 
     * @param id 交易明细记录主键
     * @return 交易明细记录
     */
    public AppTransactionDetails selectAppTransactionDetailsById(Long id);

    /**
     * 查询交易明细记录列表
     * 
     * @param appTransactionDetails 交易明细记录
     * @return 交易明细记录集合
     */
    public List<AppTransactionDetails> selectAppTransactionDetailsList(AppTransactionDetails appTransactionDetails);

    /**
     * 新增交易明细记录
     * 
     * @param appTransactionDetails 交易明细记录
     * @return 结果
     */
    public int insertAppTransactionDetails(AppTransactionDetails appTransactionDetails);

    /**
     * 修改交易明细记录
     * 
     * @param appTransactionDetails 交易明细记录
     * @return 结果
     */
    public int updateAppTransactionDetails(AppTransactionDetails appTransactionDetails);

    /**
     * 批量删除交易明细记录
     * 
     * @param ids 需要删除的交易明细记录主键集合
     * @return 结果
     */
    public int deleteAppTransactionDetailsByIds(Long[] ids);

    /**
     * 删除交易明细记录信息
     * 
     * @param id 交易明细记录主键
     * @return 结果
     */
    public int deleteAppTransactionDetailsById(Long id);

    /**
     * 查询交易明细记录列表
     *
     * @param wid 钱包编号
     * @return 交易明细记录集合
     */
    public List<AppTransactionDetails> getAppTransactionDetailsByWid(Long wid);
}
